import events = require('@aws-cdk/aws-events');
import cdk = require('@aws-cdk/cdk');
import { Action } from './actions';
import { cloudformation } from './codepipeline.generated';
import { Pipeline } from './pipeline';
/**
 * A stage in a pipeline. Stages are added to a pipeline by constructing a Stage with
 * the pipeline as the first argument to the constructor.
 *
 * @example
 * // add a stage to a pipeline
 * new Stage(pipeline, 'MyStage');
 */
export declare class Stage extends cdk.Construct {
    /**
     * The Pipeline this stage is a member of
     */
    readonly pipeline: Pipeline;
    private readonly _actions;
    /**
     * Append a new stage to the pipeline
     *
     * Only a Pipeline can be passed in as a parent because stages should
     * always be attached to a pipeline. It's illogical to construct a Stage
     * with any other parent.
     */
    constructor(parent: Pipeline, name: string);
    /**
     * Get a duplicate of this stage's list of actions.
     */
    readonly actions: Action[];
    validate(): string[];
    render(): cloudformation.PipelineResource.StageDeclarationProperty;
    onStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * If an action is added as a child, add it to the list of actions.
     * TODO: This is a hack that should be removed once the CDK has an
     *       onChildAdded type hook.
     * @override
     * @param child
     * @param name
     */
    protected addChild(child: cdk.Construct, name: string): void;
    private validateHasActions;
}
