import { Construct } from '@aws-cdk/cdk';
import { TopicName } from './sns.generated';
import { TopicArn, TopicRef } from './topic-ref';
/**
 * Properties for a new SNS topic
 */
export interface TopicProps {
    /**
     * A developer-defined string that can be used to identify this SNS topic.
     *
     * @default None
     */
    displayName?: string;
    /**
     * A name for the topic.
     *
     * If you don't specify a name, AWS CloudFormation generates a unique
     * physical ID and uses that ID for the topic name. For more information,
     * see Name Type.
     *
     * @default Generated name
     */
    topicName?: string;
}
/**
 * A new SNS topic
 */
export declare class Topic extends TopicRef {
    readonly topicArn: TopicArn;
    readonly topicName: TopicName;
    protected readonly autoCreatePolicy: boolean;
    constructor(parent: Construct, name: string, props?: TopicProps);
}
